@@ -1,21 +1,19 @@
 import asyncio
 import pytmi
 
-
 async def main() -> None:
     nick = input("Insert your Twitch nickname: ").strip()
     token = input("Insert your Twitch OAuth token: ").strip()
     channel = input("Insert the channel to join: ").strip()
 
-    client = pytmi.Client()
-    await client.login_oauth(token, nick)
+    async with pytmi.Client() as client:
+        await client.login_oauth(token, nick, channel)
 
-    await client.join(channel)
-    await client.privmsg("Hello, Twitch!")
-
-    await client.part(channel)
-    await client.logout()
+        await client.join(channel)
+        await client.send_message("Hello, Twitch!")
 
+        await client.part(channel)
+        await client.logout()
 
 if __name__ == "__main__":
     try:
